'use strict';

var _eslint = require('eslint');

var _magicString = require('magic-string');

var _magicString2 = _interopRequireDefault(_magicString);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

module.exports = function eslint(options = {}) {
  const cli = new _eslint.CLIEngine(options);
  let formatter = options.formatter;

  if (typeof formatter !== 'function') {
    formatter = cli.getFormatter(formatter || 'stylish');
  }

  return {
    name: 'eslint-bundle',

    transformBundle(code) {
      const report = cli.executeOnText(code);

      const hasWarnings = options.throwOnWarning && report.warningCount !== 0;
      const hasErrors = options.throwOnError && report.errorCount !== 0;

      if (report.warningCount || report.errorCount) {
        const result = formatter(report.results);

        if (result) {
          console.log(result);
        }

        if (hasWarnings && hasErrors) {
          throw Error('Warnings or errors were found');
        } else if (hasWarnings) {
          throw Error('Warnings were found');
        } else if (hasErrors) {
          throw Error('Errors were found');
        }
      }

      const result = {
        code,
        map: null
      };

      if (options.fix) {
        result.code = report.results[0].output;

        if (options.sourcemap !== false) {
          result.map = new _magicString2.default(result.code).generateMap({ hires: true });
        }
      }

      return result;
    }
  };
};